@@ -1,8 +1,8 @@
 #ifndef _GST_PLUGINS_BASE__STDINT_H
 #define _GST_PLUGINS_BASE__STDINT_H 1
 #ifndef _GENERATED_STDINT_H
-#define _GENERATED_STDINT_H "gst-plugins-base 0.10.23.3"
-/* generated using gnu compiler gcc (Ubuntu 4.3.3-5ubuntu4) 4.3.3 */
+#define _GENERATED_STDINT_H "gst-plugins-base 0.10.27"
+/* generated using gnu compiler gcc (Debian 4.4.3-2) 4.4.3 */
 #define _STDINT_HAVE_STDINT_H 1
 #include <stdint.h>
 #endif
